@@ -248,39 +248,38 @@
 #include "etc/cling/Interpreter/RuntimeOptions.h"
 #include "etc/cling/Interpreter/Value.h"
 #include "etc/cling/Interpreter/Visibility.h"
-#define ROOFIT_BUILDS_ITSELF
-// ./core/clingutils/G__vectorDict.cxx
-#include "vector"
-// ./core/clingutils/G__multisetDict.cxx
-#include "set"
-// ./core/clingutils/G__listDict.cxx
-#include "list"
 // ./core/clingutils/G__forward_listDict.cxx
 #include "forward_list"
+// ./core/clingutils/G__listDict.cxx
+#include "list"
+// ./core/clingutils/G__vectorDict.cxx
+#include "vector"
 // ./core/clingutils/G__dequeDict.cxx
 #include "deque"
+// ./core/clingutils/G__multisetDict.cxx
+#include "set"
 // ./core/clingutils/G__setDict.cxx
 #include "set"
-// ./core/clingutils/G__unordered_setDict.cxx
-#include "unordered_set"
-// ./core/clingutils/G__unordered_multimapDict.cxx
-#include "unordered_map"
-// ./core/clingutils/G__map2Dict.cxx
-#include "map"
-// ./core/clingutils/G__mapDict.cxx
-#include "map"
 // ./core/clingutils/G__multimap2Dict.cxx
 #include "map"
 // ./core/clingutils/G__multimapDict.cxx
 #include "map"
+// ./core/clingutils/G__unordered_setDict.cxx
+#include "unordered_set"
+// ./core/clingutils/G__mapDict.cxx
+#include "map"
+// ./core/clingutils/G__map2Dict.cxx
+#include "map"
 // ./core/clingutils/G__unordered_multisetDict.cxx
 #include "unordered_set"
-// ./core/clingutils/G__unordered_mapDict.cxx
-#include "unordered_map"
 // ./core/clingutils/G__valarrayDict.cxx
 #include "valarray"
+// ./core/clingutils/G__unordered_multimapDict.cxx
+#include "unordered_map"
 // ./core/clingutils/G__complexDict.cxx
 #include "root_std_complex.h"
+// ./core/clingutils/G__unordered_mapDict.cxx
+#include "unordered_map"
 // ./core/imt/G__Imt.cxx
 #include "ROOT/TTaskGroup.hxx"
 #include "ROOT/RTaskArena.hxx"
@@ -316,7 +315,6 @@
 #include "TThread.h"
 #include "TThreadImp.h"
 #include "TThreadPool.h"
-#include "ROOT/RConcurrentHashColl.hxx"
 #include "ROOT/TRWSpinLock.hxx"
 #include "ROOT/TSpinMutex.hxx"
 #include "ROOT/TThreadedObject.hxx"
@@ -391,7 +389,6 @@
 #include "Math/SpecFuncMathCore.h"
 #include "Math/StdEngine.h"
 #include "Math/TDataPoint.h"
-#include "Math/TDataPointN.h"
 #include "Math/TRandomEngine.h"
 #include "Math/Types.h"
 #include "Math/Util.h"
@@ -505,7 +502,6 @@
 #include "Minuit2/ExternalInternalGradientCalculator.h"
 #include "Minuit2/FCNAdapter.h"
 #include "Minuit2/FCNBase.h"
-#include "Minuit2/FCNGradAdapter.h"
 #include "Minuit2/FCNGradientBase.h"
 #include "Minuit2/FumiliBuilder.h"
 #include "Minuit2/FumiliChi2FCN.h"
@@ -552,16 +548,16 @@
 #include "Minuit2/MnMinos.h"
 #include "Minuit2/MnParabola.h"
 #include "Minuit2/MnParabolaFactory.h"
-#include "Minuit2/MnParabolaPoint.h"
 #include "Minuit2/MnParameterScan.h"
+#include "Minuit2/MnParameterTransformation.h"
 #include "Minuit2/MnPlot.h"
+#include "Minuit2/MnPoint.h"
 #include "Minuit2/MnPosDef.h"
 #include "Minuit2/MnPrint.h"
 #include "Minuit2/MnScan.h"
 #include "Minuit2/MnSeedGenerator.h"
 #include "Minuit2/MnSimplex.h"
 #include "Minuit2/MnStrategy.h"
-#include "Minuit2/MnTiny.h"
 #include "Minuit2/MnTraceObject.h"
 #include "Minuit2/MnUserCovariance.h"
 #include "Minuit2/MnUserFcn.h"
@@ -579,9 +575,6 @@
 #include "Minuit2/SimplexMinimizer.h"
 #include "Minuit2/SimplexParameters.h"
 #include "Minuit2/SimplexSeedGenerator.h"
-#include "Minuit2/SinParameterTransformation.h"
-#include "Minuit2/SqrtLowParameterTransformation.h"
-#include "Minuit2/SqrtUpParameterTransformation.h"
 #include "Minuit2/VariableMetricBuilder.h"
 #include "Minuit2/VariableMetricEDMEstimator.h"
 #include "Minuit2/VariableMetricMinimizer.h"
@@ -779,6 +772,7 @@
 #include "TGraphSmooth.h"
 #include "TGraphTime.h"
 #include "TScatter.h"
+#include "TScatter2D.h"
 #include "TH1C.h"
 #include "TH1D.h"
 #include "TH1F.h"
@@ -839,6 +833,20 @@
 #include "TGraphPainter.h"
 #include "THistPainter.h"
 #include "TPaletteAxis.h"
+// ./hist/histv7/G__ROOTHist.cxx
+#include "ROOT/RAxes.hxx"
+#include "ROOT/RBinIndex.hxx"
+#include "ROOT/RBinIndexRange.hxx"
+#include "ROOT/RBinWithError.hxx"
+#include "ROOT/RCategoricalAxis.hxx"
+#include "ROOT/RHist.hxx"
+#include "ROOT/RHistEngine.hxx"
+#include "ROOT/RHistStats.hxx"
+#include "ROOT/RHistUtils.hxx"
+#include "ROOT/RLinearizedIndex.hxx"
+#include "ROOT/RRegularAxis.hxx"
+#include "ROOT/RVariableBinAxis.hxx"
+#include "ROOT/RWeight.hxx"
 // ./hist/spectrum/G__Spectrum.cxx
 #include "TSpectrum.h"
 #include "TSpectrum2.h"
@@ -892,7 +900,6 @@
 #include "TLeafS.h"
 #include "TNtupleD.h"
 #include "TNtuple.h"
-#include "TQueryResult.h"
 #include "TreeUtils.h"
 #include "TSelector.h"
 #include "TSelectorList.h"
@@ -956,6 +963,11 @@
 #include "TTreeViewer.h"
 #include "TTVLVContainer.h"
 #include "TTVSession.h"
+// ./tree/ntuplebrowse/G__ROOTNTupleBrowse.cxx
+#include "ROOT/RNTupleBrowseUtils.hxx"
+#include "ROOT/RNTupleClassicBrowse.hxx"
+#include "ROOT/RNTupleDrawVisitor.hxx"
+#include "ROOT/RNTupleTreeMap.hxx"
 // ./tree/webviewer/G__ROOTTreeViewer.cxx
 #include "ROOT/RTreeViewer.hxx"
 // ./tree/dataframe/G__ROOTDataFrame.cxx
@@ -979,6 +991,7 @@
 #include "ROOT/RDF/InterfaceUtils.hxx"
 #include "ROOT/RDF/RActionBase.hxx"
 #include "ROOT/RDF/RAction.hxx"
+#include "ROOT/RDF/RActionSnapshot.hxx"
 #include "ROOT/RDF/RActionImpl.hxx"
 #include "ROOT/RDF/RColumnRegister.hxx"
 #include "ROOT/RDF/RNewSampleNotifier.hxx"
@@ -1017,6 +1030,7 @@
 #include "ROOT/RDF/RVariationReader.hxx"
 #include "ROOT/RDF/RVariationsDescription.hxx"
 #include "ROOT/RDF/RVariedAction.hxx"
+#include "ROOT/RDF/SnapshotHelpers.hxx"
 #include "ROOT/RDF/Utils.hxx"
 #include "ROOT/RDF/PyROOTHelpers.hxx"
 #include "ROOT/RDF/RDFDescription.hxx"
@@ -1049,7 +1063,9 @@
 #include "ROOT/RNTupleReadOptions.hxx"
 #include "ROOT/RNTupleReader.hxx"
 #include "ROOT/RNTupleSerialize.hxx"
+#include "ROOT/RNTupleTypes.hxx"
 #include "ROOT/RNTupleUtil.hxx"
+#include "ROOT/RNTupleUtils.hxx"
 #include "ROOT/RNTupleView.hxx"
 #include "ROOT/RNTupleWriteOptions.hxx"
 #include "ROOT/RNTupleWriteOptionsDaos.hxx"
@@ -1068,6 +1084,8 @@
 #include "ROOT/RNTupleExporter.hxx"
 #include "ROOT/RNTupleInspector.hxx"
 // ./io/io/G__RIO.cxx
+#include "ROOT/RConcurrentHashColl.hxx"
+#include "ROOT/RFile.hxx"
 #include "ROOT/RRawFile.hxx"
 #include "ROOT/RRawFileTFile.hxx"
 #include "ROOT/RRawFileUnix.hxx"
@@ -1487,6 +1505,9 @@
 #include "TFitEditor.h"
 #include "TFitParametersDialog.h"
 #include "TTreeInput.h"
+// ./gui/treemap/G__ROOTTreeMap.cxx
+#include "ROOT/RTreeMapBase.hxx"
+#include "ROOT/RTreeMapPainter.hxx"
 // ./gui/fitpanelv7/G__ROOTFitPanelv7.cxx
 #include "ROOT/RFitPanel.hxx"
 #include "ROOT/RFitPanelModel.hxx"
@@ -1669,6 +1690,7 @@
 #include "TMVA/BatchGenerator/RBatchGenerator.hxx"
 #include "TMVA/BatchGenerator/RBatchLoader.hxx"
 #include "TMVA/BatchGenerator/RChunkLoader.hxx"
+#include "TMVA/BatchGenerator/RChunkConstructor.hxx"
 // ./tmva/tmvagui/G__TMVAGui.cxx
 #include "TMVA/BDT.h"
 #include "TMVA/BDTControlPlots.h"
@@ -1846,6 +1868,7 @@
 #include "RooEllipse.h"
 #include "RooErrorHandler.h"
 #include "RooErrorVar.h"
+#include "RooEvaluatorWrapper.h"
 #include "RooExpensiveObjectCache.h"
 #include "RooExtendPdf.h"
 #include "RooExtendedBinding.h"
@@ -1880,7 +1903,6 @@
 #include "RooFitResult.h"
 #include "RooFormulaVar.h"
 #include "RooFracRemainder.h"
-#include "RooFuncWrapper.h"
 #include "RooFunctor.h"
 #include "RooGenContext.h"
 #include "RooGenFitStudy.h"
@@ -1906,6 +1928,8 @@
 #include "RooMoment.h"
 #include "RooMsgService.h"
 #include "RooMultiCategory.h"
+#include "RooMultiPdf.h"
+#include "RooMultiReal.h"
 #include "RooMultiVarGaussian.h"
 #include "RooNameReg.h"
 #include "RooNormSetCache.h"
@@ -2002,6 +2026,7 @@
 #include "RooFunctor1DBinding.h"
 #include "RooFunctorBinding.h"
 #include "RooGamma.h"
+#include "RooGaussExpTails.h"
 #include "RooGaussian.h"
 #include "RooGaussModel.h"
 #include "RooGExpModel.h"
@@ -2057,7 +2082,6 @@
 #include "RooStats/FeldmanCousins.h"
 #include "RooStats/FrequentistCalculator.h"
 #include "RooStats/Heaviside.h"
-#include "RooStats/HLFactory.h"
 #include "RooStats/HybridCalculator.h"
 #include "RooStats/HybridPlot.h"
 #include "RooStats/HybridResult.h"
