@@ -45,6 +45,7 @@ class RooCmdArg;
 class TGraph;
 class TGraphErrors;
 class TMultiGraph;
+class TFile;
 
 namespace RooStats {
 class HypoTestResult;
@@ -82,7 +83,8 @@ public:
 
    void reinitialize();
 
-   void AddOption(const RooCmdArg &opt);
+   void SetOption(const RooCmdArg &opt);
+   [[deprecated("Use SetOption()")]] void AddOption(const RooCmdArg &opt) { SetOption(opt); }
 
    std::pair<std::shared_ptr<RooAbsData>, std::shared_ptr<const RooAbsCollection>>
    getData() const; // returns pointer to data and snapshot of globs
@@ -239,11 +241,32 @@ public:
       double fNullVal();
       double fAltVal();
 
+      void setNullVal(double val);
+      void setAltVal(double val);
+      void setObsTS(double val, double err)
+      {
+         obs_ts = val;
+         obs_ts_err = err;
+         fPllType = xRooFit::Asymptotics::Unknown;
+      }
+      void addNullToy(double value, double weight = 1., int seed = 0)
+      {
+         fPllType = xRooFit::Asymptotics::Unknown;
+         nullToys.emplace_back(std::make_tuple(seed, value, weight));
+      }
+      void addAltToy(double value, double weight = 1., int seed = 0)
+      {
+         fPllType = xRooFit::Asymptotics::Unknown;
+         altToys.emplace_back(std::make_tuple(seed, value, weight));
+      }
+
       std::shared_ptr<const RooAbsCollection> coords; // pars of the nll that will be held const alongside POI
 
       std::shared_ptr<const RooFitResult> fUfit, fNull_cfit, fAlt_cfit, fLbound_cfit;
       std::shared_ptr<const RooFitResult> fGenFit; // if the data was generated, this is the fit is was generated from
       bool isExpected = false;                     // if genFit, flag says is asimov or not
+      double obs_ts = std::numeric_limits<double>::quiet_NaN(); // only specified for unknown pll types
+      double obs_ts_err = std::numeric_limits<double>::quiet_NaN();
 
       std::shared_ptr<xRooHypoPoint>
          fAsimov; // same as this point but pllType is twosided and data is expected post alt-fit
@@ -288,7 +311,8 @@ public:
 
       bool AddModel(const xRooNode &pdf, const char *validity = "");
 
-      void LoadFits(const char *apath);
+      // the directory where fits are cached from scans
+      TDirectory *fitCache() const { return fFitDb.get(); }
 
       // A points over given parameter, number of points between low and high
       int AddPoints(const char *parName, size_t nPoints, double low, double high);
@@ -366,21 +390,26 @@ public:
       std::map<std::shared_ptr<xRooNode>, std::shared_ptr<xRooNLLVar>> fNlls; // existing NLL functions of added pdfs;
 
       std::set<std::pair<std::shared_ptr<RooArgList>, std::shared_ptr<xRooNode>>> fPdfs;
+
+      std::shared_ptr<TDirectory> fFitDb;
    };
 
    xRooHypoSpace hypoSpace(const char *parName, int nPoints, double low, double high,
                            double alt_value = std::numeric_limits<double>::quiet_NaN(),
-                           const xRooFit::Asymptotics::PLLType &pllType = xRooFit::Asymptotics::Unknown);
+                           const xRooFit::Asymptotics::PLLType &pllType = xRooFit::Asymptotics::Unknown,
+                           int tsType = 0);
    xRooHypoSpace hypoSpace(const char *parName = "",
                            const xRooFit::Asymptotics::PLLType &pllType = xRooFit::Asymptotics::Unknown,
                            double alt_value = std::numeric_limits<double>::quiet_NaN());
    xRooHypoSpace hypoSpace(int nPoints, double low, double high,
                            double alt_value = std::numeric_limits<double>::quiet_NaN(),
                            const xRooFit::Asymptotics::PLLType &pllType = xRooFit::Asymptotics::Unknown);
-   xRooHypoSpace hypoSpace(const char *parName, xRooFit::TestStatistic::Type tsType, int nPoints = 0)
+   xRooHypoSpace hypoSpace(const char *parName, xRooFit::TestStatistic::Type tsType, int nPoints = 0,
+                           double low = -std::numeric_limits<double>::infinity(),
+                           double high = std::numeric_limits<double>::infinity(),
+                           double alt_value = std::numeric_limits<double>::quiet_NaN())
    {
-      return hypoSpace(parName, int(tsType), nPoints, -std::numeric_limits<double>::infinity(),
-                       std::numeric_limits<double>::infinity());
+      return hypoSpace(parName, nPoints, low, high, alt_value, xRooFit::Asymptotics::Unknown, tsType);
    }
 
    std::shared_ptr<RooArgSet> pars(bool stripGlobalObs = true) const;
