@@ -24,6 +24,7 @@
 #include "RConfigure.h"
 #include <functional>
 #include <cassert>
+#include <memory>
 #include <string>
 #include <vector>
 #include "TFormula.h"
@@ -33,9 +34,12 @@
 #include "TAttMarker.h"
 #include "TF1AbsComposition.h"
 #include "TMath.h"
+#include "TMatrixDSymfwd.h"
 #include "Math/Types.h"
 #include "Math/ParamFunctor.h"
 
+#include <string>
+
 class TF1;
 class TH1;
 class TAxis;
@@ -109,9 +113,8 @@ public:
    {
       std::copy(params, params + fParameters.size(), fParameters.begin());
    }
-   void  SetParameters(Double_t p0, Double_t p1, Double_t p2 = 0, Double_t p3 = 0, Double_t p4 = 0,
-                       Double_t p5 = 0, Double_t p6 = 0, Double_t p7 = 0, Double_t p8 = 0,
-                       Double_t p9 = 0, Double_t p10 = 0);
+   template <typename... Args>
+   void   SetParameters(Double_t arg1, Args &&... args);
 
    void   SetParameter(const char *name, Double_t value)
    {
@@ -122,12 +125,8 @@ public:
       if (!CheckIndex(iparam)) return;
       fParNames[iparam] = std::string(name);
    }
-   void   SetParNames(const char *name0 = "p0", const char *name1 = "p1", const char *name2 = "p2",
-                      const char *name3 = "p3", const char *name4 = "p4", const char *name5 = "p5",
-                      const char *name6 = "p6", const char *name7 = "p7", const char *name8 = "p8",
-                      const char *name9 = "p9", const char *name10 = "p10");
-
-
+   template <typename... Args>
+   void   SetParNames(Args &&... args);
 
    ClassDef(TF1Parameters, 1)  // The Parameters of a parameteric function
 private:
@@ -141,6 +140,28 @@ private:
    std::vector<std::string> fParNames;   // parameter names
 };
 
+/// Set parameter values.
+/// NaN values will be skipped, meaning that the corresponding parameters will not be changed.
+template <typename... Args>
+void TF1Parameters::SetParameters(Double_t arg1, Args &&...args)
+{
+   int i = 0;
+   for (double val : {arg1, static_cast<Double_t>(args)...}) {
+      if(!TMath::IsNaN(val)) SetParameter(i++, val);
+   }
+}
+
+/// Set parameter names.
+/// Empty strings will be skipped, meaning that the corresponding name will not be changed.
+template <typename... Args>
+void TF1Parameters::SetParNames(Args &&...args)
+{
+   int i = 0;
+   for (auto name : {static_cast<std::string const&>(args)...}) {
+      if(!name.empty()) SetParName(i++, name.c_str());
+   }
+}
+
 namespace ROOT {
    namespace Internal {
       /// %Internal class used by TF1 for defining
@@ -154,58 +175,6 @@ namespace ROOT {
       struct TF1Builder<Func *> {
          static void Build(TF1 *f, Func *func);
       };
-
-      /// %Internal class used by TF1 for obtaining the type from a functor
-      /// out of the set of valid operator() signatures.
-      template<typename T>
-      struct GetFunctorType {
-      };
-
-      template<typename F, typename T>
-      struct GetFunctorType<T(F::*)(const T *, const double *)> {
-         using type = T;
-      };
-
-      template<typename F, typename T>
-      struct GetFunctorType<T(F::*)(const T *, const double *) const> {
-         using type = T;
-      };
-
-      template<typename F, typename T>
-      struct GetFunctorType<T(F::*)(T *, double *)> {
-         using type = T;
-      };
-
-      template<typename F, typename T>
-      struct GetFunctorType<T(F::*)(T *, double *) const> {
-         using type = T;
-      };
-
-      /// %Internal class used by TF1 to get the right operator() signature
-      /// from a Functor with several ones.
-      template<typename T, typename F>
-      auto GetTheRightOp(T(F::*opPtr)(const T *, const double *)) -> decltype(opPtr)
-      {
-         return opPtr;
-      }
-
-      template<typename T, typename F>
-      auto GetTheRightOp(T(F::*opPtr)(const T *, const double *) const) -> decltype(opPtr)
-      {
-         return opPtr;
-      }
-
-      template<typename T, typename F>
-      auto GetTheRightOp(T(F::*opPtr)(T *, double *)) -> decltype(opPtr)
-      {
-         return opPtr;
-      }
-
-      template<typename T, typename F>
-      auto GetTheRightOp(T(F::*opPtr)(T *, double *) const) -> decltype(opPtr)
-      {
-         return opPtr;
-      }
    }
 }
 
@@ -282,9 +251,9 @@ protected:
 private:
    // NSUM parsing helper functions
    void DefineNSUMTerm(TObjArray *newFuncs, TObjArray *coeffNames,
-		       TString &fullFormula,
-		       TString &formula, int termStart, int termEnd,
-		       Double_t xmin, Double_t xmax);
+               TString &fullFormula,
+               TString &formula, int termStart, int termEnd,
+               Double_t xmin, Double_t xmax);
    int TermCoeffLength(TString &term);
 
 protected:
@@ -293,8 +262,8 @@ protected:
    struct TF1FunctorPointerImpl: TF1FunctorPointer {
       TF1FunctorPointerImpl(const ROOT::Math::ParamFunctorTempl<T> &func): fImpl(func) {};
       TF1FunctorPointerImpl(const std::function<T(const T *f, const Double_t *param)> &func) : fImpl(func){};
-      virtual ~TF1FunctorPointerImpl() {}
-      virtual  TF1FunctorPointer * Clone() const { return new TF1FunctorPointerImpl<T>(fImpl); }
+      ~TF1FunctorPointerImpl() override {}
+       TF1FunctorPointer * Clone() const override { return new TF1FunctorPointerImpl<T>(fImpl); }
       ROOT::Math::ParamFunctorTempl<T> fImpl;
    };
 
@@ -318,6 +287,8 @@ protected:
    virtual void GetRange(Double_t *xmin, Double_t *xmax) const;
    virtual TH1 *DoCreateHistogram(Double_t xmin, Double_t xmax, Bool_t recreate = kFALSE);
 
+   TString ProvideSaveName(Option_t *option);
+
 public:
 
    // TF1 status bits
@@ -343,13 +314,18 @@ public:
    ////////////////////////////////////////////////////////////////////////////////
    /// Constructor using a pointer to function.
    ///
-   /// \param npar is the number of free parameters used by the function
+   /// \param[in] name object name
+   /// \param[in] fcn pointer to function
+   /// \param[in] xmin,xmax x axis limits
+   /// \param[in] npar is the number of free parameters used by the function
+   /// \param[in] ndim number of dimensions
+   /// \param[in] addToGlobList boolean marking if it should be added to global list
    ///
    /// This constructor creates a function of type C when invoked
    /// with the normal C++ compiler.
    ///
    ///
-   /// WARNING! A function created with this constructor cannot be Cloned
+   /// \warning A function created with this constructor cannot be Cloned
 
 
    template <class T>
@@ -406,7 +382,7 @@ public:
 
    TF1(const TF1 &f1);
    TF1 &operator=(const TF1 &rhs);
-   virtual   ~TF1();
+     ~TF1() override;
    virtual void     AddParameter(const TString &name, Double_t value)
    {
       if (fFormula) fFormula->AddParameter(name, value);
@@ -416,31 +392,35 @@ public:
    // virtual void     AddVariables(const TString *vars, Int_t size) { if (fFormula) fFormula->AddVariables(vars,size); }
    virtual Bool_t   AddToGlobalList(Bool_t on = kTRUE);
    static  Bool_t   DefaultAddToGlobalList(Bool_t on = kTRUE);
-   virtual void     Browse(TBrowser *b);
-   virtual void     Copy(TObject &f1) const;
-   TObject*         Clone(const char* newname=0) const;
-   virtual Double_t Derivative(Double_t x, Double_t *params = 0, Double_t epsilon = 0.001) const;
-   virtual Double_t Derivative2(Double_t x, Double_t *params = 0, Double_t epsilon = 0.001) const;
-   virtual Double_t Derivative3(Double_t x, Double_t *params = 0, Double_t epsilon = 0.001) const;
+   void     Browse(TBrowser *b) override;
+   void     Copy(TObject &f1) const override;
+   TObject         *Clone(const char *newname = nullptr) const override;
+   virtual Double_t Derivative(Double_t x, Double_t *params = nullptr, Double_t epsilon = 0.001) const;
+   virtual Double_t Derivative2(Double_t x, Double_t *params = nullptr, Double_t epsilon = 0.001) const;
+   virtual Double_t Derivative3(Double_t x, Double_t *params = nullptr, Double_t epsilon = 0.001) const;
    static  Double_t DerivativeError();
-   virtual Int_t    DistancetoPrimitive(Int_t px, Int_t py);
-   virtual void     Draw(Option_t *option = "");
+   Int_t    DistancetoPrimitive(Int_t px, Int_t py) override;
+   void     Draw(Option_t *option = "") override;
    virtual TF1     *DrawCopy(Option_t *option = "") const;
    virtual TObject *DrawDerivative(Option_t *option = "al"); // *MENU*
    virtual TObject *DrawIntegral(Option_t *option = "al"); // *MENU*
    virtual void     DrawF1(Double_t xmin, Double_t xmax, Option_t *option = "");
    virtual Double_t Eval(Double_t x, Double_t y = 0, Double_t z = 0, Double_t t = 0) const;
    //template <class T> T Eval(T x, T y = 0, T z = 0, T t = 0) const;
-   virtual Double_t EvalPar(const Double_t *x, const Double_t *params = 0);
-   template <class T> T EvalPar(const T *x, const Double_t *params = 0);
+   virtual Double_t EvalPar(const Double_t *x, const Double_t *params = nullptr);
+   template <class T> T EvalPar(const T *x, const Double_t *params = nullptr);
    virtual Double_t operator()(Double_t x, Double_t y = 0, Double_t z = 0, Double_t t = 0) const;
    template <class T> T operator()(const T *x, const Double_t *params = nullptr);
-   virtual void     ExecuteEvent(Int_t event, Int_t px, Int_t py);
+   Double_t EvalUncertainty(Double_t x, const TMatrixDSym *covMatrix = nullptr) const;
+   void     ExecuteEvent(Int_t event, Int_t px, Int_t py) override;
    virtual void     FixParameter(Int_t ipar, Double_t value);
-   bool      IsVectorized()
+   /// Return true if function has data in fSave buffer
+   Bool_t HasSave() const { return !fSave.empty(); }
+   bool IsVectorized()
    {
       return (fType == EFType::kTemplVec) || (fType == EFType::kFormula && fFormula && fFormula->IsVectorized());
    }
+   /// Return the Chisquare after fitting. See ROOT::Fit::FitResult::Chi2()
    Double_t     GetChisquare() const
    {
       return fChisquare;
@@ -460,7 +440,7 @@ public:
    }
    virtual TString  GetExpFormula(Option_t *option = "") const
    {
-      return (fFormula) ? fFormula->GetExpFormula(option) : "";
+      return (fFormula) ? fFormula->GetExpFormula(option) : TString();
    }
    virtual const TObject *GetLinearPart(Int_t i) const
    {
@@ -504,7 +484,7 @@ public:
    {
       return fNpfits;
    }
-   virtual char    *GetObjectInfo(Int_t px, Int_t py) const;
+   char    *GetObjectInfo(Int_t px, Int_t py) const override;
    TObject    *GetParent() const
    {
       return fParent;
@@ -535,13 +515,17 @@ public:
       return (fFormula) ? fFormula->GetParNumber(name) : fParams->GetParNumber(name);
    }
    virtual Double_t GetParError(Int_t ipar) const;
+   virtual Double_t GetParError(const char *name) const
+   {
+      return GetParError(GetParNumber(name));
+   }
    virtual const Double_t *GetParErrors() const
    {
       return fParErrors.data();
    }
    virtual void     GetParLimits(Int_t ipar, Double_t &parmin, Double_t &parmax) const;
    virtual Double_t GetProb() const;
-   virtual Int_t    GetQuantiles(Int_t nprobSum, Double_t *q, const Double_t *probSum);
+   virtual Int_t    GetQuantiles(Int_t n, Double_t *xp, const Double_t *p);
    virtual Double_t GetRandom(TRandom * rng = nullptr, Option_t * opt = nullptr);
    virtual Double_t GetRandom(Double_t xmin, Double_t xmax, TRandom * rng = nullptr, Option_t * opt = nullptr);
    virtual void     GetRange(Double_t &xmin, Double_t &xmax) const;
@@ -564,26 +548,26 @@ public:
    {
       return (fFormula) ? fFormula->GetVariable(name) : 0;
    }
-   virtual Double_t GradientPar(Int_t ipar, const Double_t *x, Double_t eps = 0.01);
+   virtual Double_t GradientPar(Int_t ipar, const Double_t *x, Double_t eps = 0.01) const;
    template <class T>
-   T GradientPar(Int_t ipar, const T *x, Double_t eps = 0.01);
+   T GradientPar(Int_t ipar, const T *x, Double_t eps = 0.01) const;
    template <class T>
-   T GradientParTempl(Int_t ipar, const T *x, Double_t eps = 0.01);
+   T GradientParTempl(Int_t ipar, const T *x, Double_t eps = 0.01) const;
 
-   virtual void     GradientPar(const Double_t *x, Double_t *grad, Double_t eps = 0.01);
+   virtual void     GradientPar(const Double_t *x, Double_t *grad, Double_t eps = 0.01) const;
    template <class T>
-   void GradientPar(const T *x, T *grad, Double_t eps = 0.01);
+   void GradientPar(const T *x, T *grad, Double_t eps = 0.01) const;
    template <class T>
-   void GradientParTempl(const T *x, T *grad, Double_t eps = 0.01);
+   void GradientParTempl(const T *x, T *grad, Double_t eps = 0.01) const;
 
    virtual void     InitArgs(const Double_t *x, const Double_t *params);
    static  void     InitStandardFunctions();
    virtual Double_t Integral(Double_t a, Double_t b, Double_t epsrel = 1.e-12);
    virtual Double_t IntegralOneDim(Double_t a, Double_t b, Double_t epsrel, Double_t epsabs, Double_t &err);
-   virtual Double_t IntegralError(Double_t a, Double_t b, const Double_t *params = 0, const Double_t *covmat = 0, Double_t epsilon = 1.E-2);
-   virtual Double_t IntegralError(Int_t n, const Double_t *a, const Double_t *b, const Double_t *params = 0, const Double_t *covmat = 0, Double_t epsilon = 1.E-2);
-   // virtual Double_t IntegralFast(const TGraph *g, Double_t a, Double_t b, Double_t *params=0);
-   virtual Double_t IntegralFast(Int_t num, Double_t *x, Double_t *w, Double_t a, Double_t b, Double_t *params = 0, Double_t epsilon = 1e-12);
+   virtual Double_t IntegralError(Double_t a, Double_t b, const Double_t *params = nullptr, const Double_t *covmat = nullptr, Double_t epsilon = 1.E-2);
+   virtual Double_t IntegralError(Int_t n, const Double_t *a, const Double_t *b, const Double_t *params = nullptr, const Double_t *covmat = nullptr, Double_t epsilon = 1.E-2);
+   // virtual Double_t IntegralFast(const TGraph *g, Double_t a, Double_t b, Double_t *params = nullptr);
+   virtual Double_t IntegralFast(Int_t num, Double_t *x, Double_t *w, Double_t a, Double_t b, Double_t *params = nullptr, Double_t epsilon = 1e-12);
    virtual Double_t IntegralMultiple(Int_t n, const Double_t *a, const Double_t *b, Int_t maxpts, Double_t epsrel, Double_t epsabs , Double_t &relerr, Int_t &nfnevl, Int_t &ifail);
    virtual Double_t IntegralMultiple(Int_t n, const Double_t *a, const Double_t *b, Int_t /*minpts*/, Int_t maxpts, Double_t epsrel, Double_t &relerr, Int_t &nfnevl, Int_t &ifail)
    {
@@ -604,16 +588,16 @@ public:
       return (fFormula) ? fFormula->IsLinear() : false;
    }
    virtual Bool_t   IsValid() const;
-   virtual void     Print(Option_t *option = "") const;
-   virtual void     Paint(Option_t *option = "");
+   void     Print(Option_t *option = "") const override;
+   void     Paint(Option_t *option = "") override;
    virtual void     ReleaseParameter(Int_t ipar);
    virtual void     Save(Double_t xmin, Double_t xmax, Double_t ymin, Double_t ymax, Double_t zmin, Double_t zmax);
-   virtual void     SavePrimitive(std::ostream &out, Option_t *option = "");
+   void     SavePrimitive(std::ostream &out, Option_t *option = "") override;
    virtual void     SetChisquare(Double_t chi2)
    {
       fChisquare = chi2;
    }
-   virtual void     SetFitResult(const ROOT::Fit::FitResult &result, const Int_t *indpar = 0);
+   virtual void     SetFitResult(const ROOT::Fit::FitResult &result, const Int_t *indpar = nullptr);
    template <class PtrObj, typename MemFn>
    void SetFunction(PtrObj &p, MemFn memFn);
    template <typename Func>
@@ -630,6 +614,11 @@ public:
       fNormalized = flag;
       Update();
    }
+   inline void SetNdim(Int_t ndim)
+   {
+      fNdim = ndim;
+      Update();
+   }
    virtual void     SetNpx(Int_t npx = 100); // *MENU*
    virtual void     SetParameter(Int_t param, Double_t value)
    {
@@ -646,23 +635,31 @@ public:
       (fFormula) ? fFormula->SetParameters(params) : fParams->SetParameters(params);
       Update();
    }
-   virtual void     SetParameters(Double_t p0, Double_t p1, Double_t p2 = 0, Double_t p3 = 0, Double_t p4 = 0,
-                                  Double_t p5 = 0, Double_t p6 = 0, Double_t p7 = 0, Double_t p8 = 0,
-                                  Double_t p9 = 0, Double_t p10 = 0)
+   /// Set parameter values.
+   /// NaN values will be skipped, meaning that the corresponding parameters will not be changed.
+   virtual void SetParameters(double p0, double p1 = TMath::QuietNaN(), double p2 = TMath::QuietNaN(),
+                              double p3 = TMath::QuietNaN(), double p4 = TMath::QuietNaN(), double p5 = TMath::QuietNaN(),
+                              double p6 = TMath::QuietNaN(), double p7 = TMath::QuietNaN(), double p8 = TMath::QuietNaN(),
+                              double p9 = TMath::QuietNaN(), double p10 = TMath::QuietNaN())
    {
+      // Note: this is not made a variadic template method because it would
+      // presumably break the context menu in the TBrowser. Also, probably this
+      // method should not be virtual, because if the user wants to change
+      // parameter setting behavior, the SetParameter() method can be
+      // overridden.
       if (fFormula) fFormula->SetParameters(p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p10);
       else          fParams->SetParameters(p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p10);
       Update();
    } // *MENU*
    virtual void     SetParName(Int_t ipar, const char *name);
-   virtual void     SetParNames(const char *name0 = "p0", const char *name1 = "p1", const char *name2 = "p2",
-                                const char *name3 = "p3", const char *name4 = "p4", const char *name5 = "p5",
-                                const char *name6 = "p6", const char *name7 = "p7", const char *name8 = "p8",
-                                const char *name9 = "p9", const char *name10 = "p10"); // *MENU*
+   virtual void     SetParNames(const char *name0 = "", const char *name1 = "", const char *name2 = "",
+                                const char *name3 = "", const char *name4 = "", const char *name5 = "",
+                                const char *name6 = "", const char *name7 = "", const char *name8 = "",
+                                const char *name9 = "", const char *name10 = ""); // *MENU*
    virtual void     SetParError(Int_t ipar, Double_t error);
    virtual void     SetParErrors(const Double_t *errors);
    virtual void     SetParLimits(Int_t ipar, Double_t parmin, Double_t parmax);
-   virtual void     SetParent(TObject *p = 0)
+   virtual void     SetParent(TObject *p = nullptr)
    {
       fParent = p;
    }
@@ -670,7 +667,7 @@ public:
    virtual void     SetRange(Double_t xmin, Double_t ymin,  Double_t xmax, Double_t ymax);
    virtual void     SetRange(Double_t xmin, Double_t ymin, Double_t zmin,  Double_t xmax, Double_t ymax, Double_t zmax);
    virtual void     SetSavedPoint(Int_t point, Double_t value);
-   virtual void     SetTitle(const char *title = ""); // *MENU*
+   void     SetTitle(const char *title = "") override; // *MENU*
    virtual void     SetVectorized(Bool_t vectorized)
    {
       if (fType == EFType::kFormula && fFormula)
@@ -687,13 +684,13 @@ public:
    static  void     SetCurrent(TF1 *f1);
 
    //Moments
-   virtual Double_t Moment(Double_t n, Double_t a, Double_t b, const Double_t *params = 0, Double_t epsilon = 0.000001);
-   virtual Double_t CentralMoment(Double_t n, Double_t a, Double_t b, const Double_t *params = 0, Double_t epsilon = 0.000001);
-   virtual Double_t Mean(Double_t a, Double_t b, const Double_t *params = 0, Double_t epsilon = 0.000001)
+   virtual Double_t Moment(Double_t n, Double_t a, Double_t b, const Double_t *params = nullptr, Double_t epsilon = 0.000001);
+   virtual Double_t CentralMoment(Double_t n, Double_t a, Double_t b, const Double_t *params = nullptr, Double_t epsilon = 0.000001);
+   virtual Double_t Mean(Double_t a, Double_t b, const Double_t *params = nullptr, Double_t epsilon = 0.000001)
    {
       return Moment(1, a, b, params, epsilon);
    }
-   virtual Double_t Variance(Double_t a, Double_t b, const Double_t *params = 0, Double_t epsilon = 0.000001)
+   virtual Double_t Variance(Double_t a, Double_t b, const Double_t *params = nullptr, Double_t epsilon = 0.000001)
    {
       return CentralMoment(2, a, b, params, epsilon);
    }
@@ -705,13 +702,13 @@ public:
 
 private:
    template <class T>
-   T EvalParTempl(const T *data, const Double_t *params = 0);
+   T EvalParTempl(const T *data, const Double_t *params = nullptr);
 
 #ifdef R__HAS_VECCORE
    inline double EvalParVec(const Double_t *data, const Double_t *params);
 #endif
 
-   ClassDef(TF1, 12) // The Parametric 1-D function
+   ClassDefOverride(TF1, 12) // The Parametric 1-D function
 };
 
 namespace ROOT {
@@ -720,19 +717,33 @@ namespace ROOT {
       template<class Func>
       void TF1Builder<Func>::Build(TF1 *f, Func func)
       {
-         using Fnc_t = typename ROOT::Internal::GetFunctorType<decltype(ROOT::Internal::GetTheRightOp(&Func::operator()))>::type;
-         f->fType = std::is_same<Fnc_t, double>::value? TF1::EFType::kTemplScalar : TF1::EFType::kTemplVec;
-         f->fFunctor.reset(new TF1::TF1FunctorPointerImpl<Fnc_t>(ROOT::Math::ParamFunctorTempl<Fnc_t>(func)));
-         f->fParams.reset(new TF1Parameters(f->fNpar));
+         // check if vector interface is supported by Func
+         if constexpr(std::is_invocable_r_v<Double_v, Func, Double_v*, double *>) {
+            // if ROOT was not built with veccore and vc, Double_v is just an alias for the scalar double
+            f->fType = std::is_same<Double_v, double>::value ? TF1::EFType::kTemplScalar : TF1::EFType::kTemplVec;
+            f->fFunctor.reset(new TF1::TF1FunctorPointerImpl(ROOT::Math::ParamFunctorTempl<Double_v>(func)));
+         } else {
+            f->fType = TF1::EFType::kTemplScalar;
+            f->fFunctor.reset(new TF1::TF1FunctorPointerImpl(ROOT::Math::ParamFunctorTempl<double>(func)));
+         }
+
+         f->fParams = std::make_unique<TF1Parameters>(f->fNpar);
       }
 
       template<class Func>
       void TF1Builder<Func *>::Build(TF1 *f, Func *func)
       {
-         using Fnc_t = typename ROOT::Internal::GetFunctorType<decltype(ROOT::Internal::GetTheRightOp(&Func::operator()))>::type;
-         f->fType = std::is_same<Fnc_t, double>::value? TF1::EFType::kTemplScalar : TF1::EFType::kTemplVec;
-         f->fFunctor.reset(new TF1::TF1FunctorPointerImpl<Fnc_t>(ROOT::Math::ParamFunctorTempl<Fnc_t>(func)));
-         f->fParams.reset(new TF1Parameters(f->fNpar));
+         // check if vector interface is supported by Func
+         if constexpr(std::is_invocable_r_v<Double_v, Func, Double_v*, double *>) {
+            // if ROOT was not built with veccore and vc, Double_v is just an alias for the scalar double
+            f->fType = std::is_same<Double_v, double>::value ? TF1::EFType::kTemplScalar : TF1::EFType::kTemplVec;
+            f->fFunctor.reset(new TF1::TF1FunctorPointerImpl(ROOT::Math::ParamFunctorTempl<Double_v>(func)));
+         } else {
+            f->fType = TF1::EFType::kTemplScalar;
+            f->fFunctor.reset(new TF1::TF1FunctorPointerImpl(ROOT::Math::ParamFunctorTempl<double>(func)));
+         }
+
+         f->fParams = std::make_unique<TF1Parameters>(f->fNpar);
       }
 
       /// TF1 building from a string
@@ -742,7 +753,7 @@ namespace ROOT {
          static void Build(TF1 *f, const char *formula)
          {
             f->fType = TF1::EFType::kFormula;
-            f->fFormula.reset(new TFormula("tf1lambda", formula, f->fNdim, f->fNpar, false));
+            f->fFormula = std::make_unique<TFormula>("tf1lambda", formula, f->fNdim, f->fNpar, false);
             TString formulaExpression(formula);
             Ssiz_t first = formulaExpression.Index("return") + 7;
             Ssiz_t last  = formulaExpression.Last(';');
@@ -750,6 +761,14 @@ namespace ROOT {
             f->SetTitle(title);
          }
       };
+
+      inline void
+      EvalParMultiDim(TF1 *func, Double_t *out, const Double_t *x, std::size_t size, std::size_t rows, Double_t *params)
+      {
+         for (size_t i = 0; i < rows; i++) {
+            out[i] = func->EvalPar(x + i * size, params);
+         }
+      }
    }
 }
 
@@ -840,18 +859,18 @@ void TF1::SetFunction(Func f)
 {
    // set function from a generic C++ callable object
    fType = EFType::kPtrScalarFreeFcn;
-   fFunctor.reset(new TF1::TF1FunctorPointerImpl<double>(ROOT::Math::ParamFunctor(f)));
+   fFunctor = std::make_unique<TF1::TF1FunctorPointerImpl<double>>(ROOT::Math::ParamFunctor(f));
 }
 template <class PtrObj, typename MemFn>
 void TF1::SetFunction(PtrObj &p, MemFn memFn)
 {
    // set from a pointer to a member function
    fType = EFType::kPtrScalarFreeFcn;
-   fFunctor.reset(new TF1::TF1FunctorPointerImpl<double>(ROOT::Math::ParamFunctor(p, memFn)));
+   fFunctor = std::make_unique<TF1::TF1FunctorPointerImpl<double>>(ROOT::Math::ParamFunctor(p, memFn));
 }
 
 template <class T>
-inline T TF1::GradientPar(Int_t ipar, const T *x, Double_t eps)
+inline T TF1::GradientPar(Int_t ipar, const T *x, Double_t eps) const
 {
    if (fType == EFType::kTemplVec || fType == EFType::kTemplScalar) {
       return GradientParTempl<T>(ipar, x, eps);
@@ -860,7 +879,7 @@ inline T TF1::GradientPar(Int_t ipar, const T *x, Double_t eps)
 }
 
 template <class T>
-inline T TF1::GradientParTempl(Int_t ipar, const T *x, Double_t eps)
+inline T TF1::GradientParTempl(Int_t ipar, const T *x, Double_t eps) const
 {
    if (GetNpar() == 0)
       return 0;
@@ -918,7 +937,7 @@ inline T TF1::GradientParTempl(Int_t ipar, const T *x, Double_t eps)
 }
 
 template <class T>
-inline void TF1::GradientPar(const T *x, T *grad, Double_t eps)
+inline void TF1::GradientPar(const T *x, T *grad, Double_t eps) const
 {
    if (fType == EFType::kTemplVec || fType == EFType::kTemplScalar) {
       GradientParTempl<T>(x, grad, eps);
@@ -927,7 +946,7 @@ inline void TF1::GradientPar(const T *x, T *grad, Double_t eps)
 }
 
 template <class T>
-inline void TF1::GradientParTempl(const T *x, T *grad, Double_t eps)
+inline void TF1::GradientParTempl(const T *x, T *grad, Double_t eps) const
 {
    if (eps < 1e-10 || eps > 1) {
       Warning("Derivative", "parameter esp=%g out of allowed range[1e-10,1], reset to 0.01", eps);
