@@ -8,23 +8,37 @@
 # For the list of contributors see $ROOTSYS/README/CREDITS.                    #
 ################################################################################
 
-from os import environ
-
-# Prevent cppyy's check for the PCH
-environ["CLING_STANDARD_PCH"] = "none"
-
-# Prevent cppyy's check for extra header directory
-environ["CPPYY_API_PATH"] = "none"
-
-# Prevent cppyy from filtering ROOT libraries
-environ["CPPYY_NO_ROOT_FILTER"] = "1"
-
-# Do setup specific to AddressSanitizer environments
-from . import _asan
+import atexit
+import builtins
+import os
+import sys
+import types
+from importlib.abc import Loader, MetaPathFinder
+from importlib.machinery import ModuleSpec
+from typing import Optional, Union
 
 import cppyy
-import sys, importlib
-import libROOTPythonizations
+import cppyy.types
+
+from . import _asan  # noqa: F401  # imported for side effects for setup specific to AddressSanitizer environments
+from ._facade import ROOTFacade
+from ._pythonization import _register_pythonizations
+
+# Prevent cppyy's check for extra header directory
+os.environ["CPPYY_API_PATH"] = "none"
+
+# Prevent cppyy from filtering ROOT libraries
+os.environ["CPPYY_NO_ROOT_FILTER"] = "1"
+
+# The libROOTPythonizations CPython extension is in the same directory as the
+# ROOT Python module, but to find the other ROOT libraries we need to also add
+# the path of the ROOT library directory (only needed on Windows). For example,
+# if the ROOT Python module is in $ROOTSYS/bin/ROOT/__init__.py, the libraries
+# are usually in $ROOTSYS/bin.
+if "win32" in sys.platform:
+    root_module_path = os.path.dirname(__file__)  # expected to be ${CMAKE_INSTALL_PYTHONDIR}/ROOT
+    root_install_pythondir = os.path.dirname(root_module_path)  # expected to be ${CMAKE_INSTALL_PYTHONDIR}
+    os.add_dll_directory(root_install_pythondir)
 
 # Build cache of commonly used python strings (the cache is python intern, so
 # all strings are shared python-wide, not just in PyROOT).
@@ -33,14 +47,11 @@ _cached_strings = []
 for s in ["Branch", "FitFCN", "ROOT", "SetBranchAddress", "SetFCN", "_TClass__DynamicCast", "__class__"]:
     _cached_strings.append(sys.intern(s))
 
-# Trigger the addition of the pythonizations
-from ._pythonization import _register_pythonizations
 
+# Trigger the addition of the pythonizations
 _register_pythonizations()
 
 # Check if we are in the IPython shell
-import builtins
-
 _is_ipython = hasattr(builtins, "__IPYTHON__")
 
 
@@ -64,9 +75,6 @@ class _PoisonedDunderAll:
 __all__ = _PoisonedDunderAll()
 
 # Configure ROOT facade module
-import sys
-from ._facade import ROOTFacade
-
 _root_facade = ROOTFacade(sys.modules[__name__], _is_ipython)
 sys.modules[__name__] = _root_facade
 
@@ -76,9 +84,6 @@ sys.modules[__name__] = _root_facade
 #   * https://docs.python.org/3/library/importlib.html#module-importlib.abc
 #
 #   * https://python.plainenglish.io/metapathfinders-or-how-to-change-python-import-behavior-a1cf3b5a13ec
-from importlib.abc import Loader, MetaPathFinder
-from importlib.machinery import ModuleSpec
-from importlib.util import spec_from_loader
 
 
 def _can_be_module(obj) -> bool:
@@ -100,11 +105,7 @@ def _can_be_module(obj) -> bool:
     return False
 
 
-from typing import Optional, Union
-import types
-
-
-def _lookup_root_module(fullname: str) -> Optional[Union[types.ModuleType, cppyy._backend.CPPScope]]:
+def _lookup_root_module(fullname: str) -> Optional[Union[types.ModuleType, cppyy.types.Scope]]:
     """
     Recursively looks up attributes of the ROOT facade, using a full module
     name, and return it if it can be used as a ROOT submodule. This is the case
@@ -152,6 +153,8 @@ class _RootNamespaceFinder(MetaPathFinder):
     """
 
     def find_spec(self, fullname: str, path, target=None) -> ModuleSpec:
+        from importlib.util import spec_from_loader
+
         if not fullname.startswith("ROOT."):
             # This finder only finds ROOT.*
             return None
@@ -170,11 +173,11 @@ if _is_ipython:
 
     ip = get_ipython()
     if hasattr(ip, "kernel"):
-        import JupyROOT
-        from . import JsMVA
+        import JupyROOT  # noqa: F401  # imported the side effect of setting up JupyROOT
+
+        # from . import JsMVA
 
 # Register cleanup
-import atexit
 
 
 def cleanup():
@@ -184,4 +187,5 @@ def cleanup():
         facade.__dict__["app"].keep_polling = False
         facade.__dict__["app"].process_root_events.join()
 
+
 atexit.register(cleanup)
